<?php

declare (strict_types=1);
namespace App\Controller;

use App\JsonRpc\ChatServiceInterface;
use App\JsonRpc\UserServiceInterface;
use App\Service\RedisService;
use App\Tools\PublicData;
use App\Tools\Result;
use function Hyperf\Support\env;
use Hyperf\Context\Context;
use Hyperf\Di\Annotation\Inject;
use Hyperf\Validation\Contract\ValidatorFactoryInterface;
/**
 *
 * Class ChatController
 * @package App\Controller
 */
//#[AutoController]
class ChatController extends AbstractController
{
    use \Hyperf\Di\Aop\ProxyTrait;
    use \Hyperf\Di\Aop\PropertyHandlerTrait;
    function __construct()
    {
        if (method_exists(parent::class, '__construct')) {
            parent::__construct(...func_get_args());
        }
        $this->__handlePropertyHandler(__CLASS__);
    }
    #[Inject]
    protected ValidatorFactoryInterface $validationFactory;
    /**
     * @var ChatServiceInterface
     */
    #[Inject]
    private $chatServiceClient;
    #[Inject]
    private UserServiceInterface $userServiceClient;
    /**
     * 申请添加好友
     * @return array
     */
    public function addFriend()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make($requireData, ['friend_id' => 'required'], ['friend_id.required' => '好友ID不能为空']);
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        //判断UserId是否是friend_id
        $userId = $requireData['user_id'];
        $friendId = $requireData['friend_id'];
        if ($userId == $friendId) {
            return Result::error('不能添加自己为好友');
        }
        //判断friend_id是否可用
        $friendInfo = $this->userServiceClient->getUserInfo((int) $friendId);
        if ($friendInfo['code'] == 0) {
            return Result::error('好友ID不存在');
        }
        $result = $this->chatServiceClient->addFriend($requireData);
        //redis 添加好友
        if ($result && $result['code'] != 0) {
            $redisClient = new RedisService();
            $myFriends = $this->chatServiceClient->getFriendsList(['user_id' => $userId, 'status' => 2]);
            $redisClient->setUserFriends($userId, $myFriends['data']);
        }
        return $result ? Result::success($result['message']) : Result::error($result['message']);
    }
    /**
     * 话题分类
     * @return array
     */
    public function topicType()
    {
        $type = array('1' => '课题', '2' => '维权', '3' => '讨论');
        $result = array();
        foreach ($type as $k => $v) {
            $result[] = ['value' => $k, 'label' => $v];
        }
        return Result::success($result);
    }
    /**
     * 获取话题列表
     * @return array
     */
    public function topicStatus()
    {
        $status = array('1' => '未审核', '2' => '已通过', '3' => '已拒绝');
        $result = array();
        foreach ($status as $k => $v) {
            $result[] = ['value' => $k, 'label' => $v];
        }
        return Result::success($result);
    }
    /**
     * 搜索好友列表
     * @return array
     */
    public function searchFriend()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make($requireData, ['keyword' => 'required'], ['keyword.required' => '搜索关键字不能为空']);
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        // return Result::success($requireData);
        $result = $this->chatServiceClient->searchFriend($requireData);
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 获取好友详情
     * @return array
     */
    public function getFriendInfo()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make($requireData, ['friend_id' => 'required'], ['friend_id.required' => '好友ID不能为空']);
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $result = $this->chatServiceClient->getFriendInfo($requireData);
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 获取我的好友列表
     * @return array
     */
    public function getFriendsList()
    {
        $requireData = [];
        $requireData['user_id'] = Context::get("UserId");
        $requireData['status'] = 2;
        $result = $this->chatServiceClient->getFriendsList($requireData);
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 获取好友申请列表
     * @return array
     */
    public function getFriendsApplyList()
    {
        $requireData = [];
        $requireData['friend_id'] = Context::get("UserId");
        $requireData['status'] = 1;
        $result = $this->chatServiceClient->getFriendsApplyList($requireData);
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 好友申请审核通过或拒绝
     * @return array
     */
    public function applyFriend()
    {
        $requireData = $this->request->all();
        // 定义验证规则
        $validator = $this->validationFactory->make($requireData, ['id' => 'required|integer', 'status' => 'required|in:2,4'], ['friend_id.required' => 'ID不能为空', 'status.required' => '状态不能为空', 'status.in' => '状态错误']);
        // 验证请求数据
        if ($validator->fails()) {
            var_dump($validator->errors()->all());
            return Result::error(implode(', ', $validator->errors()->all()), 0);
        }
        $requireData['user_id'] = Context::get("UserId");
        $result = $this->chatServiceClient->applyFriend($requireData);
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 删除好友
     * @return array
     */
    public function delFriend()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make($requireData, ['friend_id' => 'required'], ['friend_id.required' => '好友ID不能为空']);
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $result = $this->chatServiceClient->delFriend($requireData);
        //redis 删除好友
        if ($result && $result['code'] != 0) {
            $redisClient = new RedisService();
            $myFriends = $this->chatServiceClient->getFriendsList(['user_id' => $requireData['user_id'], 'status' => 2]);
            $redisClient->setUserFriends($requireData['user_id'], $myFriends['data']);
        }
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 是否好友
     * @return array
     */
    public function isFriend()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make($requireData, ['friend_id' => 'required'], ['friend_id.required' => '好友ID不能为空']);
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
        }
        $requireData['user_id'] = Context::get("UserId");
        $result = $this->chatServiceClient->isFriend($requireData);
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 更新好友备注
     * @return array
     */
    public function updateFriend()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make($requireData, ['friend_id' => 'required', 'remark' => 'required'], ['friend_id.required' => '好友ID不能为空', 'remark.required' => '备注不能为空']);
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $result = $this->chatServiceClient->updateFriend($requireData);
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 会话
     * @return array
     */
    public function getConversation()
    {
        $requireData = $this->request->all();
        $requireData['user_id'] = Context::get("UserId");
        $result = $this->chatServiceClient->getConversation($requireData);
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 获取聊天记录
     * @return array
     */
    public function getChatRecords()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make($requireData, ['friend_id' => 'required'], ['friend_id.required' => '好友ID不能为空']);
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $result = $this->chatServiceClient->getChatRecords($requireData);
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 获取群聊天
     * @return array
     */
    public function getGroupChatRecords()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make($requireData, ['group_id' => 'required'], ['group_id.required' => '群ID不能为空']);
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
        }
        $requireData['user_id'] = Context::get("UserId");
        $result = $this->chatServiceClient->getGroupChatRecords($requireData);
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 获取群成员列表
     * @return array
     */
    public function getGroupMembers()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make($requireData, ['group_id' => 'required'], ['group_id.required' => '群ID不能为空']);
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $result = $this->chatServiceClient->getGroupMembers($requireData);
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 获取群信息
     * @return array
     */
    public function getGroupInfo()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make($requireData, ['group_id' => 'required'], ['group_id.required' => '群ID不能为空']);
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
        }
        $requireData['user_id'] = Context::get("UserId");
        $result = $this->chatServiceClient->getGroupInfo($requireData);
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 获取群列表
     * @return array
     */
    public function getGroupList()
    {
        $requireData = $this->request->all();
        $requireData['user_id'] = Context::get("UserId");
        $result = $this->chatServiceClient->getGroupList($requireData);
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 新建群
     * @return array
     */
    public function addGroup()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make($requireData, ['group_name' => 'required', 'group_desc' => 'required'], ['group_name.required' => '群名称不能为空', 'group_desc.required' => '群描述不能为空']);
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $requireData['group_member'] = explode(',', $requireData['group_member']);
        $result = $this->chatServiceClient->addGroup($requireData);
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 退出群
     * @return array
     */
    public function quitGroup()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make($requireData, ['group_id' => 'required'], ['group_id.required' => '群ID不能为空']);
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
        }
        $requireData['user_id'] = Context::get("UserId");
        $result = $this->chatServiceClient->quitGroup($requireData);
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 删除群
     * @return array
     */
    public function delGroup()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make($requireData, ['group_id' => 'required'], ['group_id.required' => '群ID不能为空']);
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $result = $this->chatServiceClient->delGroup($requireData);
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 删除群成员
     * @return array
     */
    public function delGroupMembers()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make($requireData, ['group_id' => 'required', 'group_member' => 'required'], ['group_id.required' => '群ID不能为空', 'group_member.required' => '群成员不能为空']);
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $requireData['group_member'] = explode(',', $requireData['group_member']);
        $result = $this->chatServiceClient->delGroupMembers($requireData);
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 添加群成员
     * @return array
     */
    public function updateGroupMembers()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make($requireData, ['group_id' => 'required', 'group_member' => 'required'], ['group_id.required' => '群ID不能为空', 'group_member.required' => '群成员不能为空']);
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $requireData['group_member'] = explode(',', $requireData['group_member']);
        $result = $this->chatServiceClient->updateGroupMembers($requireData);
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 删除群成员
     * @return array
     */
    public function deleteGroupMember()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make($requireData, ['group_id' => 'required', 'group_member' => 'required'], ['group_id.required' => '群ID不能为空', 'group_member.required' => '群成员不能为空']);
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $requireData['group_member'] = explode(',', $requireData['group_member']);
        $result = $this->chatServiceClient->deleteGroupMember($requireData);
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 加入群
     * @return array
     */
    public function joinGroup()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make($requireData, ['group_id' => 'required'], ['group_id.required' => '群ID不能为空']);
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $result = $this->chatServiceClient->joinGroup($requireData);
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 更新群信息
     * @return array
     */
    public function updateGroup()
    {
        $requireData = $this->request->all();
        // 只接受指定的四个字段
        $validatedData = $this->validationFactory->make($requireData, ['group_id' => 'required|string', 'group_name' => 'nullable|string', 'profile' => 'nullable|string', 'avatar' => 'nullable|string'], ['group_id.required' => '群ID不能为空']);
        if ($validatedData->fails()) {
            $errorMessage = $validatedData->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $result = $this->chatServiceClient->updateGroup($requireData);
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 获取商圈
     * @return array
     */
    public function getTopicsList()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make($requireData, ['page' => 'required|integer', 'page_size' => 'required|integer'], ['page.required' => '页码不能为空', 'page_size.required' => '每页数量不能为空']);
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $result = $this->chatServiceClient->getTopicsList($requireData);
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 新增话题商圈
     * @return array
     */
    public function addTopic()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make($requireData, ['title' => 'required|string', 'type' => 'required|string', 'content' => 'required|string'], ['title.required' => '商圈名称不能为空', 'type.required' => '商圈类型不能为空', 'content.required' => '商圈内容不能为空']);
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $result = $this->chatServiceClient->addTopic($requireData);
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 更新话题商圈
     * @return array
     */
    public function updateTopic()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make($requireData, ['id' => 'required|string'], ['topic_id.required' => '商圈ID不能为空']);
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $result = $this->chatServiceClient->updateTopic($requireData);
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 删除话题商圈
     * @return array
     */
    public function delTopic()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make($requireData, ['id' => 'required|string'], ['id.required' => '商圈ID不能为空']);
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $result = $this->chatServiceClient->delTopic($requireData);
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 获取商圈详情
     * @return array
     */
    public function getTopicInfo()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make($requireData, ['id' => 'required|string'], ['id.required' => '商圈ID不能为空']);
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $result = $this->chatServiceClient->getTopicInfo($requireData);
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 获取商圈回复
     * @return array
     */
    public function addReply()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make($requireData, ['id' => 'required|string', 'content' => 'required|string'], ['id.required' => '商圈ID不能为空', 'content.required' => '回复内容不能为空']);
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $result = $this->chatServiceClient->addReply($requireData);
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 获取商圈评论
     * @return array
     */
    public function getTopicReply()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make($requireData, ['id' => 'required|string', 'page' => 'required|integer', 'page_size' => 'required|integer'], ['id.required' => '商圈ID不能为空', 'page.required' => '页码不能为空', 'page_size.required' => '每页数量不能为空']);
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $result = $this->chatServiceClient->getTopicReply($requireData);
        return $result && $result['code'] != 0 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**-=-------------------------------------------------------
     * 获取好友列表
     * @return array
     */
    public function getContactList()
    {
        $requireData = $this->request->all();
        $requireData['user_id'] = Context::get("UserId");
        $requireData['keyWord'] = $this->request->input('keyWord', '');
        $result = $this->chatServiceClient->getContactList($requireData);
        return $result ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 获取会话列表
     * @return array
     */
    public function getTalkSessionList()
    {
        $requireData = $this->request->all();
        $requireData['user_id'] = Context::get("UserId");
        var_dump("会话列表：", $requireData);
        $result = $this->chatServiceClient->getTalkSessionList($requireData);
        var_dump($result);
        if ($result['data']['row']) {
            foreach ($result['data']['row'] as $k => $v) {
                $result['data']['row'][$k]['messages'] = [];
            }
        }
        return $result ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 创建用户群
     * @return array
     */
    public function addTalkGroup()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make($requireData, ['group_name' => 'required', 'user_id_arr' => 'required'], ['group_name.required' => '群名称不能为空', 'user_id_arr.required' => '好友ID不能为空']);
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $requireData['user_id_arr'] = $requireData['user_id_arr'];
        var_dump($requireData);
        $result = $this->chatServiceClient->addTalkGroup($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 会话详情
     * @return void
     */
    public function getTalkRecordsList()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make($requireData, ['session_id' => 'required', 'talk_type' => 'required'], ['session_id.required' => '会话ID不能为空', 'talk_type.required' => '会话类型不能为空']);
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['page'] = $requireData['page'] ?? 1;
        $requireData['pageSize'] = $requireData['pageSize'] ?? 30;
        $result = $this->chatServiceClient->getTalkRecordsList($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 添加聊天
     * @return void
     */
    public function addTalkRecords()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make($requireData, ['type' => 'required', 'content' => 'required', 'receiver' => 'required'], ['type.required' => '消息类型不能为空', 'content.required' => '内容不能为空', 'receiver.required' => '会话信息不能为空']);
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $result = $this->chatServiceClient->addTalkRecords($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 获取openId
     * @return array|void
     */
    public function wechatOpenInfo()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make($requireData, ['code' => 'required'], ['code.required' => 'code不能为空']);
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $url = env("WECHAT") . "sns/jscode2session?appid=" . env("APPID") . "&secret=" . env("APP_SECRET") . "&js_code=" . $requireData['code'] . "&grant_type=authorization_code";
        $result = PublicData::http_get($url);
        $resultData = json_decode($result, true);
        if (isset($resultData['errcode'])) {
            return Result::error($resultData['errmsg']);
        }
        return Result::success($resultData);
    }
    /**
     * 获取 access_token
     * @return array
     */
    public function getAccessToken()
    {
        $url = env("WECHAT") . "cgi-bin/token?appid=" . env("APPID") . "&secret=" . env("APP_SECRET") . "&grant_type=client_credential";
        $result = PublicData::http_get($url);
        $resultData = json_decode($result, true);
        var_dump($url, $resultData);
        if (isset($resultData['errcode'])) {
            return Result::error($resultData['errmsg']);
        }
        return Result::success($resultData);
    }
}